/*
 
*** Audio Player Example 3 for ATE-550 from Antratek Electronics ***

Based on Arduino Sound library and WavePlayback example on arduino.cc and RTClib->ds3231 demo.
 
Created in 2023 by André Veenstra

This example is a kind of cuckoo clock. Every hour it plays an audiotrack. At one o'clock it plays track001,
at two o'clock track002, and so on.
At a push on test button or high at sensor input the track of the current hour is played.
The rotary switch is used to adjust volume and the LED is on during playing.
 
*/

#include <SD.h>
#include <ArduinoSound.h>
#include <Wire.h>
#include "RTClib.h"
RTC_DS3231 rtc;

char daysOfTheWeek[7][12] = {"Sunday", "Monday", "Tuesday", "Wednesday", "Thursday", "Friday", "Saturday"};

// filename of wave file to play
const char filename1[] = "track001.wav";
const char filename2[] = "track002.wav";
const char filename3[] = "track003.wav";
const char filename4[] = "track004.wav";
const char filename5[] = "track005.wav";
const char filename6[] = "track006.wav";
const char filename7[] = "track007.wav";
const char filename8[] = "track008.wav";
const char filename9[] = "track009.wav";
const char filename10[] = "track010.wav";
const char filename11[] = "track011.wav";
const char filename12[] = "track012.wav";

// variable representing the Wave File
SDWaveFile waveFile;

int counter = 0;          //indicates which audio file is next
int test = 5;             //number of pin with test button
int inputpin = 6;         //number of pin to which input door sensor is connected
int led = 12;             //number of pin with led
int prevteststate = 1;    //previous test button state
int prevsensorstate = 0;  //previous sensor status
int sensoractive = 0;     //sensor was activated
int vol = 20;             //sound volume
int bcd1 = 15;            //pin 1 to 4 of BCD switch for volume
int bcd2 = 16;
int bcd4 = 17;
int bcd8 = 18;
int cuckoo = 1;           //number of track to be played
int currenthour = 1;      //current hour

void setup() {
// Open serial communications and wait for port to open:
//  Serial.begin(9600);
//  delay(3000); // wait for console opening

  // initialize pins
  pinMode(LED_BUILTIN, OUTPUT);  
  pinMode(led, OUTPUT);
  pinMode(test, INPUT_PULLUP);
  pinMode(inputpin, INPUT);
  pinMode(bcd1, INPUT_PULLUP);
  pinMode(bcd2, INPUT_PULLUP);
  pinMode(bcd4, INPUT_PULLUP);
  pinMode(bcd8, INPUT_PULLUP);

  digitalWrite(LED_BUILTIN, HIGH);  // to indicate power is on
   
  // setup the SD card, depending on your shield of breakout board
  // you may need to pass a pin number in begin for SS
//  Serial.print("Initializing SD card...");
  if (!SD.begin(4)) {
//    Serial.println("initialization failed!");
    digitalWrite(led, HIGH);
    while (1);  // do nothing, led will stay on to indicate SD card is missing
  }
  else {
//    Serial.println("initialization done.");
  digitalWrite(led, HIGH);
  delay(500);       // short led flash indicates that player is initialized correctly
  digitalWrite(led, LOW);
  }
  // check if the I2S output can play the first wave file
  waveFile = SDWaveFile(filename1);
  if (!AudioOutI2S.canPlay(waveFile)) {
//    Serial.println("unable to play wave file using I2S!");
    digitalWrite(led, HIGH);
    while (1); // do nothing, led will stay on to indicate valid file is missing
  }

  if (! rtc.begin()) {
//    Serial.println("Couldn't find RTC");
    digitalWrite(led, HIGH);
    while (1);  // do nothing, led will stay on to indicate RTC is missing
  }

  if (rtc.lostPower()) {
//    Serial.println("RTC lost power, lets set the time!");
    // following line sets the RTC to the date & time this sketch was compiled
    rtc.adjust(DateTime(F(__DATE__), F(__TIME__)));
    // This line sets the RTC with an explicit date & time, for example to set
    // January 21, 2014 at 3am you would call:
    // rtc.adjust(DateTime(2014, 1, 21, 3, 0, 0));
  }
  DateTime now = rtc.now();
  currenthour = now.hour();
}

 
void loop() {
  // check if playback is still going on
  if (!AudioOutI2S.isPlaying()) {
    // playback has stopped
  digitalWrite(led, LOW);         // turn the LED off
//    Serial.println("playback stopped");
  if (digitalRead(inputpin) == HIGH && prevsensorstate == 0) {
    delay(100);              //wait 0.1 sec after sensor
    prevsensorstate = 1;
  }
  if (digitalRead(inputpin) == LOW && prevsensorstate == 1){   //start playback when status of door sensor changed 
    prevsensorstate = 0;
    sensoractive = 1;
    playAudio();
    sensoractive = 0;
  }
  if (digitalRead(test) == HIGH) {
    prevteststate = 1;
  }
  if (digitalRead(test) == LOW && prevteststate == 1){   //start playback when status of test button changed 
    prevteststate = 0;
    playAudio();
  }
  delay(100);                                          //check if there is a new hour
  DateTime now = rtc.now();
  if (now.hour() != currenthour){
    currenthour = now.hour();
    playAudio();
  }
  }
}

void playAudio()  {    
    counter++;
//    Serial.print("Counter is ");
//    Serial.println(counter);
    digitalWrite(led, HIGH);         // turn the LED on
    vol = 10;   //minimum volume if BCD switch volume is 0
    if (digitalRead(bcd1) == LOW){
      vol = vol + 10;
    }
    if (digitalRead(bcd2) == LOW){
      vol = vol + 20;
    }
    if (digitalRead(bcd4) == LOW){
      vol = vol + 40;
    }
    if (digitalRead(bcd8) == LOW){
      vol = vol + 80;
    }
//    Serial.print("Volume is ");
//    Serial.println(vol);    
    AudioOutI2S.volume(vol);// adjust the playback volume

    DateTime now = rtc.now();
    
/*    Serial.print(now.year(), DEC);
    Serial.print('/');
    Serial.print(now.month(), DEC);
    Serial.print('/');
    Serial.print(now.day(), DEC);
    Serial.print(" (");
    Serial.print(daysOfTheWeek[now.dayOfTheWeek()]);
    Serial.print(") ");
    Serial.print(now.hour(), DEC);
    Serial.print(':');
    Serial.print(now.minute(), DEC);
    Serial.print(':');
    Serial.print(now.second(), DEC);
    Serial.println(); 
    Serial.println();
*/
    if (now.hour() > 11) {
      cuckoo = now.hour() - 12;     //change 13-24 hours to 1-12 hours
    }
    if (now.hour() < 12) {
      cuckoo = now.hour();
    }
//    Serial.print(currenthour, DEC);
//    Serial.print('>');
//    Serial.print(cuckoo, DEC);
//    Serial.println();
    
    if (cuckoo == 1) {
//      Serial.println("starting playback file 1");
      waveFile = SDWaveFile(filename1);   // start playback 1
      AudioOutI2S.play(waveFile);
    }
    if (cuckoo == 2) {
//      Serial.println("starting playback file 2");
      waveFile = SDWaveFile(filename2);   // start playback 2
      AudioOutI2S.play(waveFile);
    }
    if (cuckoo == 3) {
//      Serial.println("starting playback file 3");
      waveFile = SDWaveFile(filename3);   // start playback 3
      AudioOutI2S.play(waveFile);
    }
    if (cuckoo == 4) {
//      Serial.println("starting playback file 4");
      waveFile = SDWaveFile(filename4);   // start playback 4
      AudioOutI2S.play(waveFile);
    }
    if (cuckoo == 5) {
//      Serial.println("starting playback file 5");
      waveFile = SDWaveFile(filename5);   // start playback 5
      AudioOutI2S.play(waveFile);
    }
    if (cuckoo == 6) {
//      Serial.println("starting playback file 6");
      waveFile = SDWaveFile(filename6);   // start playback 6
      AudioOutI2S.play(waveFile);
    }
        if (cuckoo == 7) {
//      Serial.println("starting playback file 7");
      waveFile = SDWaveFile(filename7);   // start playback 7
      AudioOutI2S.play(waveFile);
    }
        if (cuckoo == 8) {
//      Serial.println("starting playback file 8");
      waveFile = SDWaveFile(filename8);   // start playback 8
      AudioOutI2S.play(waveFile);
    }
        if (cuckoo == 9) {
//      Serial.println("starting playback file 9");
      waveFile = SDWaveFile(filename9);   // start playback 9
      AudioOutI2S.play(waveFile);
    }
        if (cuckoo == 10) {
//      Serial.println("starting playback file 10");
      waveFile = SDWaveFile(filename10);   // start playback 10
      AudioOutI2S.play(waveFile);
    }
        if (cuckoo == 11) {
//      Serial.println("starting playback file 11");
      waveFile = SDWaveFile(filename11);   // start playback 11
      AudioOutI2S.play(waveFile);
    }
        if (cuckoo == 0) {
//      Serial.println("starting playback file 12");
      waveFile = SDWaveFile(filename12);   // start playback 12
      AudioOutI2S.play(waveFile);
    }
  }


